# ----------------------- tidyverse -------------------------------------

#' @export
#' @importFrom ipmisc "%>%"
ipmisc::`%>%`

#' @export
#' @importFrom ipmisc "%<>%"
ipmisc::`%<>%`

#' @export
#' @importFrom ipmisc "%$%"
ipmisc::`%$%`

#' @export
#' @importFrom ipmisc "%<-%"
ipmisc::`%<-%`

#' @export
#' @importFrom rlang "%||%"
rlang::`%||%`

#' @export
#' @importFrom rlang "%|%"
rlang::`%|%`

#' @export
#' @importFrom rlang ":="
rlang::`:=`

#' @export
#' @importFrom ipmisc tibble
ipmisc::tibble

#' @export
#' @importFrom ipmisc as_tibble
ipmisc::as_tibble

# ----------------------- easystats -------------------------------------

#' @export
#' @importFrom correlation correlation
correlation::correlation
